Mesa (gallium-0.2): glsl: fix broken sampler assignments

Alan Hourihane alanh at kemper.freedesktop.org
Fri Jan 16 16:45:07 UTC 2009


Module: Mesa
Branch: gallium-0.2
Commit: e442fe5ba53acf16c78339f19921d70dba3928f6
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=e442fe5ba53acf16c78339f19921d70dba3928f6

Author: Brian Paul <brianp at vmware.com>
Date:   Fri Jan 16 09:30:37 2009 -0700

glsl: fix broken sampler assignments

---

 src/mesa/shader/slang/slang_emit.c |    3 ++-
 1 files changed, 2 insertions(+), 1 deletions(-)

diff --git a/src/mesa/shader/slang/slang_emit.c b/src/mesa/shader/slang/slang_emit.c
index 6b744d7..ea446fa 100644
--- a/src/mesa/shader/slang/slang_emit.c
+++ b/src/mesa/shader/slang/slang_emit.c
@@ -1349,9 +1349,10 @@ emit_copy(slang_emit_info *emitInfo, slang_ir_node *n)
 
    if (n->Store->File == PROGRAM_SAMPLER) {
       /* no code generated for sampler assignments,
        * just copy the sampler index at compile time.
        */
       n->Store->Index = n->Children[1]->Store->Index;
+      n->Store->TexTarget = n->Children[1]->Store->TexTarget;
       return NULL;
    }
 
@@ -1349,9 +1349,10 @@ emit_copy(slang_emit_info *emitInfo, slang_ir_node *n)
    if (n->Store->File == PROGRAM_SAMPLER) {
       /* no code generated for sampler assignments,
-       * just copy the sampler index at compile time.
+       * just copy the sampler index/target at compile time.
        */
       n->Store->Index = n->Children[1]->Store->Index;




More information about the mesa-commit mailing list